@@ -272,7 +272,7 @@ class Nag_Task
     /**
      * Task tags (lazy loaded).
      *
-     * @var array
+     * @var string
      */
     protected $_tags;
 
@@ -946,7 +946,7 @@ class Nag_Task
                     'task'
                 );
             }
-            $this->_tags = $this->internaltags;
+            $this->_tags = implode(',', $this->internaltags);
         } else {
             $this->_tags = $tags;
         }
@@ -1363,13 +1363,13 @@ class Nag_Task
         /* Due Date */
         if (!empty($this->due)) {
             $message->utcduedate = new Horde_Date($this->due);
-            $message->duedate = new Horde_Date($this->due, 'UTC');
+            $message->duedate = clone($message->utcduedate);
         }
 
         /* Start Date */
         if (!empty($this->start)) {
             $message->utcstartdate = new Horde_Date($this->start);
-            $message->startdate = new Horde_Date($this->start, 'UTC');
+            $message->startdate = clone($message->utcstartdate);
         }
 
         /* Priority */
@@ -1525,6 +1525,12 @@ class Nag_Task
         /* Owner is always current user. */
         $this->owner = $GLOBALS['registry']->getAuth();
 
+        /* Must set _tags so we don't lazy load tags from the backend in the
+         * case that this is an edit. For edits, all current tags will be passed
+         * from the client.
+         */
+        $this->_tags = array();
+
         /* Notes and Title */
         if ($message->getProtocolVersion() >= Horde_ActiveSync::VERSION_TWELVE) {
             if ($message->airsyncbasebody->type == Horde_ActiveSync::BODYPREF_TYPE_HTML) {
@@ -1550,15 +1556,44 @@ class Nag_Task
         }
 
         /* Due Date */
-        if (($due = $message->utcduedate) || ($due = $message->duedate)) {
+        if ($due = $message->utcduedate) {
             $due->setTimezone($tz);
             $this->due = $due->timestamp();
+        } elseif ($due = $message->duedate) {
+            // "Local" date, sent as a UTC datetime string,
+            // but must be interpreted as a local time. Since
+            // we have no timezone information we have to assume it's the
+            // same as $tz.
+            $due = new Horde_Date(
+                array(
+                    'year' => $due->year,
+                    'month' => $due->month,
+                    'mday' => $due->mday,
+                    'hour' => $due->hour,
+                    'min' => $due->min
+                ),
+                $tz
+            );
+            $this->due = $due->timestamp();
         }
 
         /* Start Date */
-        if (($start = $message->utcstartdate) || ($start = $message->startdate)) {
+        if ($start = $message->utcstartdate) {
             $start->setTimezone($tz);
             $this->start = $start->timestamp();
+        } elseif ($start = $message->startdate) {
+            // See note above regarding utc vs local times.
+            $start = new Horde_Date(
+                array(
+                    'year' => $start->year,
+                    'month' => $start->month,
+                    'mday' => $start->mday,
+                    'hour' => $start->hour,
+                    'min' => $start->min
+                ),
+                $tz
+            );
+            $this->start = $start->timestamp();
         }
 
         /* Priority */
@@ -1589,7 +1624,7 @@ class Nag_Task
 
         /* Categories */
         if (is_array($message->categories) && count($message->categories)) {
-            $this->tags = $message->categories;
+            $this->tags = implode(',', $message->categories);
         }
     }
 
